==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/departments/loadDepartment.php <==
<?php
$deptName = (isset($_REQUEST['deptName']) && strlen($_REQUEST['deptName']) >=1) ? $_REQUEST['deptName'] : '';
$deptMode = (isset($_REQUEST['deptMode']) && strlen($_REQUEST['deptMode']) >=1) ? $_REQUEST['deptMode'] : '';
if ($deptMode == 'addDept')	{
	$deptText = 'Add Department';
	$deptClass = 'icon-plus';
	$deptcn = $deptguid = $telephonenumber = $description = $currenthome = $voicemailenabled = $voicemailaccesscode = $messageboxlicense = $outofhoursmode = $timeplan = $company = $distributiongroup = $distributionmode = $distributionskiponnotargets = $alternatedistributiongroup = $alternatedistributionmode = $alternatedistributionskiponnotargets = $alternatedistributiongroup2 = $alternatedistributionmode2 = $alternatedistributionskiponnotargets2 = $outofhoursdistributiongroup = $outofhoursdistributionmode = $maxringbeforeannouncementtime = $repeatannouncementtime = $maxringbeforealternatedistributiontime = $maxringbeforealternatedistributiontime2 = $maxnumberofactivecallsbeforebusy = $wrapuptime = $noanswertime = $maxnoanswertimebeforevoicemail = $maxnoanswertimebeforevoicemailooh = '';
	
	$sr=ldap_list($ds,"cn=Departments","(&(objectclass=department)(!(cn=InboundRecordings))(!(cn=OutboundRecordings)))", array('telephonenumber'));
	$info = ldap_get_entries($ds, $sr); 
	for ($m=0; $m<$info['count']; $m++) {
	    $extn[$m] = ($info[$m]['telephonenumber'][0]);
	}
	
	$sr = ldap_read($ds,"cn=OutboundRecordings, cn=Departments","(objectclass=Department)"); $info = ldap_get_entries($ds,$sr); 
	$OutboundRecordings = (isset($info[0]['telephonenumber'][0]) && strlen($info[0]['telephonenumber'][0]) >=1) ? $info[0]['telephonenumber'][0] : NULL;
	
	$sr = ldap_read($ds,"cn=InboundRecordings, cn=Departments","(objectclass=Department)"); $info = ldap_get_entries($ds,$sr); 
	$InboundRecordings = (isset($info[0]['telephonenumber'][0]) && strlen($info[0]['telephonenumber'][0]) >=1) ? $info[0]['telephonenumber'][0] : NULL;

	$telephonenumber = max($extn) +1;
	
	if ($telephonenumber == $OutboundRecordings || $telephonenumber == $InboundRecordings) {
		while ($telephonenumber == $OutboundRecordings || $telephonenumber == $InboundRecordings){
			$telephonenumber = $telephonenumber +1;
		}
	}
	
} else {
	$deptText = ' - Edit Department';
	$deptClass = 'icon-pencil2';

	$sr=ldap_list($ds,"cn=Departments","(cn=$deptName)");
	$info = ldap_get_entries($ds, $sr); 
	
	$deptcn 					= (isset($info[0]['cn'][0]) && strlen($info[0]['cn'][0]) >=1) 											? $info[0]['cn'][0] 					: '';
	$deptguid 					= (isset($info[0]['guid'][0]) && strlen($info[0]['guid'][0]) >=1) 										? $info[0]['guid'][0] 					: '';
	$telephonenumber 			= (isset($info[0]['telephonenumber'][0]) && strlen($info[0]['telephonenumber'][0]) >=1) 				? $info[0]['telephonenumber'][0] 		: '';
	$description 	 			= (isset($info[0]['description'][0]) && strlen($info[0]['description'][0]) >=1) 						? $info[0]['description'][0] 			: '';
	$currenthome 				= (isset($info[0]['currenthome'][0]) && strlen($info[0]['currenthome'][0]) >=1) 						? $info[0]['currenthome'][0] 			: '';
	$voicemailenabled			= (isset($info[0]['voicemailenabled'][0]) && strlen($info[0]['voicemailenabled'][0]) >=1) 				? $info[0]['voicemailenabled'][0] 		: '';
	$voicemailaccesscode		= (isset($info[0]['voicemailaccesscode'][0]) && strlen($info[0]['voicemailaccesscode'][0]) >=1) 		? $info[0]['voicemailaccesscode'][0]	: '';
	$messageboxlicense			= (isset($info[0]['messageboxlicense'][0]) && strlen($info[0]['messageboxlicense'][0]) >=1) 			? $info[0]['messageboxlicense'][0] 		: '';
	$outofhoursmode				= (isset($info[0]['outofhoursmode'][0]) && strlen($info[0]['outofhoursmode'][0]) >=1) 					? $info[0]['outofhoursmode'][0] 		: '';
	$timeplan					= (isset($info[0]['timeplan'][0]) && strlen($info[0]['timeplan'][0]) >=1) 								? $info[0]['timeplan'][0] 				: '';	
	$company 					= (isset($info[0]['company'][0]) && strlen($info[0]['company'][0]) >=1) 								? $info[0]['company'][0] 				: '';

	$distributiongroup			= (isset($info[0]['distributiongroup'][0]) && strlen($info[0]['distributiongroup'][0]) >=1) 			? $info[0]['distributiongroup'][0] 		: '';
	$distributionmode			= (isset($info[0]['distributionmode'][0]) && strlen($info[0]['distributionmode'][0]) >=1) 				? $info[0]['distributionmode'][0] 		: '';
	$distributionskiponnotargets= (isset($info[0]['distributionskiponnotargets'][0]) && strlen($info[0]['distributionskiponnotargets'][0]) >=1) 	? $info[0]['distributionskiponnotargets'][0] 		: '';
	
	$alternatedistributiongroup				= (isset($info[0]['alternatedistributiongroup'][0]) && strlen($info[0]['alternatedistributiongroup'][0]) >=1) 						? $info[0]['alternatedistributiongroup'][0] 			: '';
	$alternatedistributionmode				= (isset($info[0]['alternatedistributionmode'][0]) && strlen($info[0]['alternatedistributionmode'][0]) >=1) 						? $info[0]['alternatedistributionmode'][0] 				: '';
	$alternatedistributionskiponnotargets	= (isset($info[0]['alternatedistributionskiponnotargets'][0]) && strlen($info[0]['alternatedistributionskiponnotargets'][0]) >=1) 	? $info[0]['alternatedistributionskiponnotargets'][0] 	: '';
	
	$alternatedistributiongroup2			= (isset($info[0]['alternatedistributiongroup2'][0]) && strlen($info[0]['alternatedistributiongroup2'][0]) >=1) 					? $info[0]['alternatedistributiongroup2'][0] 			: '';
	$alternatedistributionmode2				= (isset($info[0]['alternatedistributionmode2'][0]) && strlen($info[0]['alternatedistributionmode2'][0]) >=1) 						? $info[0]['alternatedistributionmode2'][0] 			: '';
	$alternatedistributionskiponnotargets2	= (isset($info[0]['alternatedistributionskiponnotargets2'][0]) && strlen($info[0]['alternatedistributionskiponnotargets2'][0]) >=1) ? $info[0]['alternatedistributionskiponnotargets2'][0] 	: '';
	
	$outofhoursdistributiongroup				= (isset($info[0]['outofhoursdistributiongroup'][0]) && strlen($info[0]['outofhoursdistributiongroup'][0]) >=1) 				? $info[0]['outofhoursdistributiongroup'][0] 			: '';
	$outofhoursdistributionmode					= (isset($info[0]['outofhoursdistributionmode'][0]) && strlen($info[0]['outofhoursdistributionmode'][0]) >=1) 					? $info[0]['outofhoursdistributionmode'][0] 			: '';
	
	$maxringbeforeannouncementtime			= (isset($info[0]['maxringbeforeannouncementtime'][0]) && strlen($info[0]['maxringbeforeannouncementtime'][0]) >=1) 						? $info[0]['maxringbeforeannouncementtime'][0] 				: '';
	$repeatannouncementtime						= (isset($info[0]['repeatannouncementtime'][0]) && strlen($info[0]['repeatannouncementtime'][0]) >=1) 									? $info[0]['repeatannouncementtime'][0] 					: '';
	$maxringbeforealternatedistributiontime		= (isset($info[0]['maxringbeforealternatedistributiontime'][0]) && strlen($info[0]['maxringbeforealternatedistributiontime'][0]) >=1)	? $info[0]['maxringbeforealternatedistributiontime'][0] 	: '';
	$maxringbeforealternatedistributiontime2	= (isset($info[0]['maxringbeforealternatedistributiontime2'][0]) && strlen($info[0]['maxringbeforealternatedistributiontime2'][0]) >=1) ? $info[0]['maxringbeforealternatedistributiontime2'][0]	: '';
	$maxnumberofactivecallsbeforebusy			= (isset($info[0]['maxnumberofactivecallsbeforebusy'][0]) && strlen($info[0]['maxnumberofactivecallsbeforebusy'][0]) >=1) 				? $info[0]['maxnumberofactivecallsbeforebusy'][0] 			: '';
	
	$wrapuptime									= (isset($info[0]['wrapuptime'][0]) && strlen($info[0]['wrapuptime'][0]) >=1) 															? $info[0]['wrapuptime'][0] 								: '';
	$noanswertime								= (isset($info[0]['noanswertime'][0]) && strlen($info[0]['noanswertime'][0]) >=1) 														? $info[0]['noanswertime'][0] 								: '';
	$maxnoanswertimebeforevoicemail				= (isset($info[0]['maxnoanswertimebeforevoicemail'][0]) && strlen($info[0]['maxnoanswertimebeforevoicemail'][0]) >=1) 					? $info[0]['maxnoanswertimebeforevoicemail'][0] 			: '';
	$maxnoanswertimebeforevoicemailooh			= (isset($info[0]['maxnoanswertimebeforevoicemailooh'][0]) && strlen($info[0]['maxnoanswertimebeforevoicemailooh'][0]) >=1) 			? $info[0]['maxnoanswertimebeforevoicemailooh'][0] 			: '';
}
?>

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/admin/departments/loadDepartment.php <==
<?php
$deptName = (isset($_REQUEST['deptName']) && strlen($_REQUEST['deptName']) >=1) ? $_REQUEST['deptName'] : '';
$deptguid = (isset($_REQUEST['deptguid']) && strlen($_REQUEST['deptguid']) >=1) ? $_REQUEST['deptguid'] : '';
$deptMode = (isset($_REQUEST['deptMode']) && strlen($_REQUEST['deptMode']) >=1) ? $_REQUEST['deptMode'] : '';
if ($deptMode == 'addDept')	{
	$deptText = 'Add Department';
	$deptClass = 'icon-plus';
	$deptcn = $deptguid = $telephonenumber = $description = $currenthome = $voicemailenabled = $voicemailaccesscode = $messageboxlicense = $outofhoursmode = $timeplan = $company = $distributiongroup = $distributionmode = $distributionskiponnotargets = $alternatedistributiongroup = $alternatedistributionmode = $alternatedistributionskiponnotargets = $alternatedistributiongroup2 = $alternatedistributionmode2 = $alternatedistributionskiponnotargets2 = $outofhoursdistributiongroup = $outofhoursdistributionmode = $maxringbeforeannouncementtime = $repeatannouncementtime = $maxringbeforealternatedistributiontime = $maxringbeforealternatedistributiontime2 = $maxnumberofactivecallsbeforebusy = $wrapuptime = $noanswertime = $maxnoanswertimebeforevoicemail = $maxnoanswertimebeforevoicemailooh = '';
	
	$sr=ldap_list($ds,"cn=Departments","(&(objectclass=department)(!(cn=InboundRecordings))(!(cn=OutboundRecordings)))", array('telephonenumber'));
	$info = ldap_get_entries($ds, $sr); 
	for ($m=0; $m<$info['count']; $m++) {
	    $extn[$m] = ($info[$m]['telephonenumber'][0]);
	}
	
	$sr = ldap_read($ds,"cn=OutboundRecordings, cn=Departments","(objectclass=Department)"); $info = ldap_get_entries($ds,$sr); 
	$OutboundRecordings = (isset($info[0]['telephonenumber'][0]) && strlen($info[0]['telephonenumber'][0]) >=1) ? $info[0]['telephonenumber'][0] : NULL;
	
	$sr = ldap_read($ds,"cn=InboundRecordings, cn=Departments","(objectclass=Department)"); $info = ldap_get_entries($ds,$sr); 
	$InboundRecordings = (isset($info[0]['telephonenumber'][0]) && strlen($info[0]['telephonenumber'][0]) >=1) ? $info[0]['telephonenumber'][0] : NULL;

	$telephonenumber = max($extn) +1;
	
	if ($telephonenumber == $OutboundRecordings || $telephonenumber == $InboundRecordings) {
		while ($telephonenumber == $OutboundRecordings || $telephonenumber == $InboundRecordings){
			$telephonenumber = $telephonenumber +1;
		}
	}
	
} else {
	$deptText = ' - Edit Department';
	$deptClass = 'icon-pencil2';

	$sr=ldap_list($ds,"cn=Departments","(guid=$deptguid)");
	$info = ldap_get_entries($ds, $sr); 
	
	$deptcn 					= (isset($info[0]['cn'][0]) && strlen($info[0]['cn'][0]) >=1) 											? $info[0]['cn'][0] 					: '';
	$deptguid 					= (isset($info[0]['guid'][0]) && strlen($info[0]['guid'][0]) >=1) 										? $info[0]['guid'][0] 					: '';
	$telephonenumber 			= (isset($info[0]['telephonenumber'][0]) && strlen($info[0]['telephonenumber'][0]) >=1) 				? $info[0]['telephonenumber'][0] 		: '';
	$description 	 			= (isset($info[0]['description'][0]) && strlen($info[0]['description'][0]) >=1) 						? $info[0]['description'][0] 			: '';
	$currenthome 				= (isset($info[0]['currenthome'][0]) && strlen($info[0]['currenthome'][0]) >=1) 						? $info[0]['currenthome'][0] 			: '';
	$voicemailenabled			= (isset($info[0]['voicemailenabled'][0]) && strlen($info[0]['voicemailenabled'][0]) >=1) 				? $info[0]['voicemailenabled'][0] 		: '';
	$voicemailaccesscode		= (isset($info[0]['voicemailaccesscode'][0]) && strlen($info[0]['voicemailaccesscode'][0]) >=1) 		? $info[0]['voicemailaccesscode'][0]	: '';
	$messageboxlicense			= (isset($info[0]['messageboxlicense'][0]) && strlen($info[0]['messageboxlicense'][0]) >=1) 			? $info[0]['messageboxlicense'][0] 		: '';
	$outofhoursmode				= (isset($info[0]['outofhoursmode'][0]) && strlen($info[0]['outofhoursmode'][0]) >=1) 					? $info[0]['outofhoursmode'][0] 		: '';
	$timeplan					= (isset($info[0]['timeplan'][0]) && strlen($info[0]['timeplan'][0]) >=1) 								? $info[0]['timeplan'][0] 				: '';	
	$company 					= (isset($info[0]['company'][0]) && strlen($info[0]['company'][0]) >=1) 								? $info[0]['company'][0] 				: '';

	$distributiongroup			= (isset($info[0]['distributiongroup'][0]) && strlen($info[0]['distributiongroup'][0]) >=1) 			? $info[0]['distributiongroup'][0] 		: '';
	$distributionmode			= (isset($info[0]['distributionmode'][0]) && strlen($info[0]['distributionmode'][0]) >=1) 				? $info[0]['distributionmode'][0] 		: '';
	$distributionskiponnotargets= (isset($info[0]['distributionskiponnotargets'][0]) && strlen($info[0]['distributionskiponnotargets'][0]) >=1) 	? $info[0]['distributionskiponnotargets'][0] 		: '';
	
	$alternatedistributiongroup				= (isset($info[0]['alternatedistributiongroup'][0]) && strlen($info[0]['alternatedistributiongroup'][0]) >=1) 						? $info[0]['alternatedistributiongroup'][0] 			: '';
	$alternatedistributionmode				= (isset($info[0]['alternatedistributionmode'][0]) && strlen($info[0]['alternatedistributionmode'][0]) >=1) 						? $info[0]['alternatedistributionmode'][0] 				: '';
	$alternatedistributionskiponnotargets	= (isset($info[0]['alternatedistributionskiponnotargets'][0]) && strlen($info[0]['alternatedistributionskiponnotargets'][0]) >=1) 	? $info[0]['alternatedistributionskiponnotargets'][0] 	: '';
	
	$alternatedistributiongroup2			= (isset($info[0]['alternatedistributiongroup2'][0]) && strlen($info[0]['alternatedistributiongroup2'][0]) >=1) 					? $info[0]['alternatedistributiongroup2'][0] 			: '';
	$alternatedistributionmode2				= (isset($info[0]['alternatedistributionmode2'][0]) && strlen($info[0]['alternatedistributionmode2'][0]) >=1) 						? $info[0]['alternatedistributionmode2'][0] 			: '';
	$alternatedistributionskiponnotargets2	= (isset($info[0]['alternatedistributionskiponnotargets2'][0]) && strlen($info[0]['alternatedistributionskiponnotargets2'][0]) >=1) ? $info[0]['alternatedistributionskiponnotargets2'][0] 	: '';
	
	$outofhoursdistributiongroup				= (isset($info[0]['outofhoursdistributiongroup'][0]) && strlen($info[0]['outofhoursdistributiongroup'][0]) >=1) 				? $info[0]['outofhoursdistributiongroup'][0] 			: '';
	$outofhoursdistributionmode					= (isset($info[0]['outofhoursdistributionmode'][0]) && strlen($info[0]['outofhoursdistributionmode'][0]) >=1) 					? $info[0]['outofhoursdistributionmode'][0] 			: '';
	
	$maxringbeforeannouncementtime			= (isset($info[0]['maxringbeforeannouncementtime'][0]) && strlen($info[0]['maxringbeforeannouncementtime'][0]) >=1) 						? $info[0]['maxringbeforeannouncementtime'][0] 				: '';
	$repeatannouncementtime						= (isset($info[0]['repeatannouncementtime'][0]) && strlen($info[0]['repeatannouncementtime'][0]) >=1) 									? $info[0]['repeatannouncementtime'][0] 					: '';
	$maxringbeforealternatedistributiontime		= (isset($info[0]['maxringbeforealternatedistributiontime'][0]) && strlen($info[0]['maxringbeforealternatedistributiontime'][0]) >=1)	? $info[0]['maxringbeforealternatedistributiontime'][0] 	: '';
	$maxringbeforealternatedistributiontime2	= (isset($info[0]['maxringbeforealternatedistributiontime2'][0]) && strlen($info[0]['maxringbeforealternatedistributiontime2'][0]) >=1) ? $info[0]['maxringbeforealternatedistributiontime2'][0]	: '';
	$maxnumberofactivecallsbeforebusy			= (isset($info[0]['maxnumberofactivecallsbeforebusy'][0]) && strlen($info[0]['maxnumberofactivecallsbeforebusy'][0]) >=1) 				? $info[0]['maxnumberofactivecallsbeforebusy'][0] 			: '';
	
	$wrapuptime									= (isset($info[0]['wrapuptime'][0]) && strlen($info[0]['wrapuptime'][0]) >=1) 															? $info[0]['wrapuptime'][0] 								: '';
	$noanswertime								= (isset($info[0]['noanswertime'][0]) && strlen($info[0]['noanswertime'][0]) >=1) 														? $info[0]['noanswertime'][0] 								: '';
	$maxnoanswertimebeforevoicemail				= (isset($info[0]['maxnoanswertimebeforevoicemail'][0]) && strlen($info[0]['maxnoanswertimebeforevoicemail'][0]) >=1) 					? $info[0]['maxnoanswertimebeforevoicemail'][0] 			: '';
	$maxnoanswertimebeforevoicemailooh			= (isset($info[0]['maxnoanswertimebeforevoicemailooh'][0]) && strlen($info[0]['maxnoanswertimebeforevoicemailooh'][0]) >=1) 			? $info[0]['maxnoanswertimebeforevoicemailooh'][0] 			: '';
}
?>
